package tetris.model;

import tetris.Tetris;
import tetris.gui.Block;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * The class Field implements the playing field of a Tetris game.
 *
 * @author Stephan Fischli
 * @version 2.1
 */
public class Field {

	/**
	 * The blocks of the field.
	 */
	private final List<Block> blocks = new ArrayList<>();

	/**
	 * Gets the blocks of the field.
	 *
	 * @return the blocks of the field
	 */
	public List<Block> getBlocks() {
		return blocks;
	}

	/**
	 * Adds blocks to the field.
	 *
	 * @param blocks the blocks to add
	 */
	public void addBlocks(Block[] blocks) {
		this.blocks.addAll(Arrays.asList(blocks));
	}

	/**
	 * Removes all blocks from the field.
	 */
	public void clear() {
		blocks.clear();
	}

	/**
	 * Detects if the specified blocks collide with the border or the blocks of the field.
	 *
	 * @param blocks the blocks to check for collision
	 * @return true if one of the blocks collides, false otherwise
	 */
	public boolean detectCollision(Block[] blocks) {
		for (Block block : blocks) {
			if (block.x < 0 || block.x >= Tetris.WIDTH || block.y < 0 || block.y >= Tetris.HEIGHT) {
				return true;
			}
			for (Block fieldBlock : this.blocks) {
				if (block.x == fieldBlock.x && block.y == fieldBlock.y) {
					return true;
				}
			}
		}
		return false;
	}
}
